{ pkgs, lib, config, ... }:
{
  config = lib.mkIf config.frogeye.extra {
    programs = {
      pandoc.enable = true;
      yt-dlp = {
        enable = true;
        settings = {
          format = "bestvideo[height<=${builtins.toString config.frogeye.desktop.maxVideoHeight}]+bestaudio/best";
          sponsorblock-mark = "all";
          sponsorblock-remove = "intro,outro,sponsor,selfpromo,preview,interaction,music_offtopic";
          sub-langs = "en,fr";
          write-auto-subs = true;
          write-subs = true;
        };
      };
    };
    home.packages = with pkgs;  ([
      # android tools
      android-tools

      # downloading
      # transmission TODO Collision if both transmissions are active?

      # Multimedia toolbox
      ffmpeg

      # documents
      visidata
      texlive.combined.scheme-full
      pdftk
      hunspell
      hunspellDicts.en_GB-ize
      hunspellDicts.en_US
      hunspellDicts.fr-moderne
      hunspellDicts.nl_NL
      # TODO libreoffice-extension-languagetool or libreoffice-extension-grammalecte-fr

    ] ++ lib.optionals config.frogeye.desktop.xorg [

      # multimedia editors
      gimp
      inkscape
      darktable
      blender
      puddletag
      musescore
      audacity

      # downloading
      transmission-qt

      # FIXME Below not on aarch64
      # wine
      wine
      # TODO wine-gecko wine-mono lib32-libpulse (?)

      # gaming
      # steam # FIXME Requires i686-linux or something. IIRC the package says to use the NixOS config and not it directly.
      yuzu-mainline
      minecraft
      # TODO factorio

    ]);
  };
}
